Reference
=========

.. currentmodule:: curies

.. autoclass:: Reference
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Reference.curie
      ~Reference.model_computed_fields
      ~Reference.model_config
      ~Reference.model_fields
      ~Reference.pair

   .. rubric:: Methods Summary

   .. autosummary::

      ~Reference.from_curie

   .. rubric:: Attributes Documentation

   .. autoattribute:: curie
   .. autoattribute:: model_computed_fields
   .. autoattribute:: model_config
   .. autoattribute:: model_fields
   .. autoattribute:: pair

   .. rubric:: Methods Documentation

   .. automethod:: from_curie
